# -*- coding: utf-8 -*-

from trac.core import *
from trac.wiki.api import IWikiMacroProvider
import inspect

__all__ = ['TracGuideTocMacro']

TOC = [('TracGuide',                    'Index'),
       ('TracInstall',                  'Installation'),
       ('TracUpgrade',                  'Upgrading'),
       ('TracIni',                      'Configuration'),
       ('TracAdmin',                    'Administration'),
       ('TracBackup',                   'Backup'),
       ('TracLogging',                  'Logging'),
       ('TracPermissions' ,             'Permissions'),
       ('TracWiki',                     'The Wiki'),
       ('WikiFormatting',               'Wiki Formatting'),
       ('TracTimeline',                 'Timeline'),
       ('TracBrowser',                  'Repository Browser'),
       ('TracChangeset',                'Changesets'),
       ('TracRoadmap',                  'Roadmap'),
       ('TracTickets',                  'Tickets'),
       ('TracQuery',                    'Ticket Queries'),
       ('TracReports',                  'Reports'),
       ('TracRss',                      'RSS Support'),
       ('TracNotification',             'Notification'),
       ('TracInterfaceCustomization',   'Customization'),
       ('TracPlugins',                  'Plugins'),
      ]

class TracGuideTocMacro(Component):
    """
    This macro shows a quick and dirty way to make a table-of-contents
    for a set of wiki pages.
    """
    
    implements(IWikiMacroProvider)
    
    # IWikiMacroProvider methods
    def get_macros(self):
        yield 'TracGuideToc'
        
    def get_macro_description(self, name):
        return inspect.getdoc(self.__class__)

    def render_macro(self, req, name, args):
	curpage = req.path_info.startswith('/wiki/') \
	          and req.path_info[6:] or 'WikiStart'
	html = '<div class="wiki-toc">' \
	       '<h4>Table of Contents</h4>' \
	       '<ul>'
	lang, page = '/' in curpage and curpage.split('/', 1) or ('', curpage)
	for ref, title in TOC:
	    if page == ref:
	        cls =  ' class="active"'
	    else:
	        cls = ''
	    html += '<li%s><a href="%s">%s</a></li>' \
	            % (cls, self.env.href.wiki(lang+ref), title)
	return html + '</ul></div>'
